%function[pend] = quadopt
global pend

% Corresponds to case 20060509controlsmainasbuiltsym of model mbquadlite2lateral
% For use with matrix elements ssmake4pv2eMB4.m/symbexport4lat.m of 5/9/06 or later.
% An approximation to the as-built controls prototype (10/11/05 build, main chain).
% Same as 20060331asbuiltsym but with measured masses from T040229-12 
% and blade spring constants recomputed directly from bounce mode frequencies. 
% All as-built numbers except off-diagonal MOI components are zeroed.

%**************************************************************************
%Updated to include Metal Quad NP values at LASTI.
%
%Locations of referenced documents with no DCC #:
% "As Designed Parameter Set 2" -
%   http://www.eng-external.rl.ac.uk/advligo/Reviews/FRR/Documents/As%20designed%20parameter%20set2.pdf
% "Useful data for Noise Prototype Quad assembly" -
%   http://www.eng-external.rl.ac.uk/advligo/documents/Useful%20data%20for%20Noise%20Prototype%20Quad%20assembly.pdf
%
%Brett Shapiro June 2008
%**************************************************************************
% Electronics egain = 165.5769963469529 
% This is the measured gain of the
% LASTI electronics (including OSEMs). It was obtained by comparing the fit
% z model with the measured z top mass response at 10 Hz, where the only important mechanical
% paramter should be the top mass mass mn. mn was measure on a scale to +-
% 10 grams (better than that originally, but probably some drift from the work at
% LASTI)
%
% Brett Shapiro 29 March 2009
%**************************************************************************
% Added another offdiagonal inertia paramter on the UIM, pend.Im1yz, which adds
% z and pitch coupling due to a front to back translation of the center of
% mass. This modification is to reflect the as built monolithic quad at
% LASTI. The front to back distance of the UIM CM is pend.h1. Similar
% parameters were added for the other stages for completeness.
%
% Many parameters, including d's and inertias were adjusted with a model
% fitting routine (BFGS algorithm) to better predict the measured dynamics
%
% Brett Shapiro 3 August 2010


                            %%%%%%%%%%%%%%%%%%%%%%%%%%%%
                            %%% Universal Parameters %%%
                            %%%%%%%%%%%%%%%%%%%%%%%%%%%%
                            pend.version = '20060509noisemainasbuiltoffdiag_wire';
                            pend.g = 9.81;
                            pend.egain = 165.5769963469529; % Measured LASTI top mass electronics gain, BNS 3/29/09 (calibrated using z model with measured masses and blade stiffnesses)
                            pend.bd = 0.01; % internal viscous damping - BNS 6/24/2008 (somewhat arbitrary, 0 damping is inconvenient in matlab and also unrealistic)
                            pend.stage2 = 1;  
                            
                            %%%%%%%%%%%%%%%%%%%%%%%%%%%%
                            %%%%%%%% Top Mass %%%%%%%%%%
                            %%%%%%%%%%%%%%%%%%%%%%%%%%%%
                            
                            % length, width, and hieght dimensions
                            pend.nx = 0.1300; % T040214-01, also "As Designed Parameter Set 2", BNS 5/15/09
                            pend.ny = 0.5000; % T040214-01, also "As Designed Parameter Set 2", BNS 5/15/09 
                            pend.nz = 0.0840; % T040214-01, also "As Designed Parameter Set 2", BNS 5/15/09 
                            
                            % density
                            pend.denn = 4000; % T040214-01, also "As Designed Parameter Set 2"
                            
                            % inertias
                            pend.mn = 21.924; % BNS - measured 11/21
                            pend.Inx = 0.462385286064711; % bfgs_monolithic_x_y_z_yaw_pitch_roll_29July2010d_part1
                            pend.Iny = 0.069939022580041; % bfgs_monolithic_x_y_z_yaw_pitch_roll_29July2010d_part1
                            pend.Inz = 0.468244632768256; % bfgs_monolithic_x_y_z_yaw_pitch_roll_29July2010d_part1
                            pend.Inxy = -0.029881327248797; % bfgs_monolithic_x_y_z_yaw_pitch_roll_29July2010d_part1
                            pend.Inyz = 0.0000439; % approximately 0, original value
                            pend.Inzx = 0.00198;   % approximately 0, original value
                            pend.hn = 0; % Front to back translation of center of mass
                            pend.Imnyz = pend.mn*pend.hn; %  The front to back translation alters the inertia matrix. This term provides coupling between z and pitch.
                            
                            
                            %%%%%%%%%%%%%%%%%%%%%%%%%%%%
                            %%%%%%%% UI Mass %%%%%%%%%%
                            %%%%%%%%%%%%%%%%%%%%%%%%%%%%
                            
                            % length, width, and hieght dimensions
                            pend.ux = 0.1300; % T040214-01, also "As Designed Parameter Set 2", BNS 5/15/09
                            pend.uy = 0.5000; % T040214-01, also "As Designed Parameter Set 2", BNS 5/15/09
                            pend.uz = 0.0840; % T040214-01, also "As Designed Parameter Set 2", BNS 5/15/09
                            
                            % density
                            pend.den1 = 4000; % T040214-01, also "As Designed Parameter Set 2"
                            
                            % inertias
                            pend.m1 = 22.005 + 0.005; % BNS - measured 11/21, +0.005 for monolithic work 5/17/2010.
                            pend.I1x = 0.508404670585712; % bfgs_monolithic_x_y_z_yaw_pitch_roll_29July2010d_part1
                            pend.I1y = 0.088657492199992; % bfgs_monolithic_x_y_z_yaw_pitch_roll_29July2010d_part1%                             
                            pend.I1z = 0.520036661955096; % bfgs_monolithic_x_y_z_yaw_pitch_roll_29July2010d_part1
                            pend.I1xy = -0.017414470113595; % bfgs_monolithic_x_y_z_yaw_pitch_roll_29July2010d_part1
                            pend.I1yz = 0;
                            pend.I1zx = 0;  
                            pend.h1 = 0.00775; % front to back (x-direction) translation of the CM. Brett Shapiro 27 June 2010
                            pend.Im1yz = pend.m1*pend.h1; %  The front to back translation alters the inertia matrix. This term provides coupling between z and pitch. Brett Shapiro 27 June 2010
                            
                            
                            %%%%%%%%%%%%%%%%%%%%%%%%%%%%
                            %%%%%%%% PUM Mass %%%%%%%%%%
                            %%%%%%%%%%%%%%%%%%%%%%%%%%%%
                            
                            % width and radius
                            pend.ix = 0.200; % "As Designed Parameter Set 2", BNS 5/15/09
                            pend.ir = 0.170; % "As Designed Parameter Set 2", BNS 5/15/09
                            
                            % density
                            pend.den2 = 2201; % density of fused silica (see note below). BNS 5/15/09 ("As Designed Parameter Set 2" says 2200)
                            
                            % inertias
                            pend.m2 = 39.63 + 0.05; % BNS - Calculated from mass (D05041), ear (D080751) and prism (D080479) drawings = 39.6405 BNS 20June2010
                            pend.I2x = 0.584099336903170; % bfgs_monolithic_x_y_z_yaw_pitch_roll_29July2010d_part1
                            pend.I2y = 0.427609985942287; % bfgs_monolithic_x_y_z_yaw_pitch_roll_29July2010d_part1
                            pend.I2z = 0.416616168785308; % bfgs_monolithic_x_y_z_yaw_pitch_roll_29July2010d_part1
                            pend.I2xy = 0;
                            pend.I2yz = 0;
                            pend.I2zx = 0;
                            pend.h2 = 0; % Front to back translation of center of mass
                            pend.Im2yz = pend.m2*pend.h2; %  The front to back translation alters the inertia matrix. This term provides coupling between z and pitch.

%                             Numerical inertia calculation with 0.025 mm resolution: Brett Shapiro July 2010. Matlab code Inertia_calc_TM_flat_and_wedge. Multiplier is from a correction on the density to make the calculated mass the same as the measured mass in code TM_and_PUM_mass.  The 0.0015 is a correction for the ears and prisms. 
%                             pend.I2x = 0.56692*1.001315706173706 + 0.0015 = 0.569165900143997 ;
%                             pend.I2y = 0.42055*1.001315706173706 = 0.421103320231352;
%                             pend.I2z = 0.41029*1.001315706173706 + 0.0015;% = 0.412329821086010;
                            
                            %%%%%%%%%%%%%%%%%%%%%%%%%%%%
                            %%%%%%%% Test Mass %%%%%%%%%
                            %%%%%%%%%%%%%%%%%%%%%%%%%%%%
                            
                            % width and radius
                            pend.tx = 0.200; % 'Proposed Steel Prism Position (from D060039)', BNS 5/15/09, also from "As Designed Parameter Set 2"
                            pend.tr = 0.170; % 'Proposed Steel Prism Position (from D060039)', BNS 5/15/09, also from "As Designed Parameter Set 2"
                            
                            % density
                            pend.den3 = 2201; % density of fused silica (see note below). BNS 5/15/09 ("As Designed Parameter Set 2" says 2200)
                            
                            % inertias
                            pend.m3 = 39.6 - 0.005; % BNS -  measured 1/20/09; 5 grams is estimate of old ear weight, removed before monolithic work                            
                            pend.I3x = 0.560801969547827; % bfgs_monolithic_x_y_z_yaw_pitch_roll_29July2010d_part1
                            pend.I3y = 0.402992079867132; % bfgs_monolithic_x_y_z_yaw_pitch_roll_29July2010d_part1
                            pend.I3z = 0.419208912160651; % bfgs_monolithic_x_y_z_yaw_pitch_roll_29July2010d_part1
                            pend.I3xy = 0;
                            pend.I3yz = 0;
                            pend.I3zx = 0;
                            pend.h3 = 0.000262; % Front to back translation of center of mass, to reflect the as-built monolithic LASTI quad. Measured from fiber violin modes of 520 Hz in back and 511 Hz in front. BNS 27 June 2010. This has little affect on the dynamics.
                            pend.Im3yz = pend.m3*pend.h3; %  The front to back translation alters the inertia matrix. This term provides coupling between z and pitch. BNS 27 June 2010
                            
%                             From Mark Barton 8 June 2010;
%                             pend.I3x = 0.566649;
%                             pend.I3y = 0.420355;  
%                             pend.I3z = 0.410092;  
                            
%                             Numerical calculation with 0.025 mm resolution: Brett Shapiro July 2010. Matlab code Inertia_calc_TM_flat_and_wedge. Multiplier is from a correction on the density to make the calculated mass the same as the measured mass in code TM_and_PUM_mass. 0.0013 is correction for ears
%                             pend.I3x = 0.56545*1.001838980303153 + 0.0013; % = 0.567789851412418 
%                             pend.I3y = 0.41878*1.001838980303153; % = 0.419550128171354
%                             pend.I3z = 0.40855*1.001838980303153 + 0.0013;% = 0.410601315402853 

                            
                            %%%%%%%%%%%%%%%%%%%%%%%%%%%%
                            %%%%%%%%%% Wires %%%%%%%%%%%
                            %%%%%%%%%%%%%%%%%%%%%%%%%%%%
                            % note: expect fiber violin modes around 493 Hz. BNS 4/25/10.
                            
                            % Lengths between effective flexure points.
                            % To get effective length subtract length
                            % between CMs by effective ds, e.g.
                            pend.ln = 0.445; % as built value BNS 7/20/2010
                            pend.l1 = 0.311; % as built value BNS 7/20/2010
                            pend.l2 = 0.342147535653900; % calculated using fact that 0.3411 is the theoretical separation between UIM and PUM CM. 0.342147535653900 = (0.3411-(0.001-pend.flex2+0.001-pend.flex2+pend.bend2))/pend.c2; This assumes blade lateral stiffnesses and flexure corrections are correct. BNS 27 July 2010 
                            % note: for wire hang pend.l2 should have been 0.328, not 0.339. This was checked on the wire jig on 27 July 2010 by BNS
                            pend.l3 = 0; % see below for actual value
                            
                            % Radii
                            pend.rn = (1.1/2)*10^-03; % "Useful data for Noise Prototype Quad assembly"; BNS 6/18/08
                            pend.r1 = (0.711/2)*10^-03; % "Useful data for Noise Prototype Quad assembly"; BNS 6/18/08
                            pend.r2 = (0.635/2)*10^-03; % "Useful data for Noise Prototype Quad assembly"; BNS 6/18/08
%                             pend.r3 = (0.457/2)*10^-03; % "Useful data for Noise Prototype Quad assembly"; BNS 6/18/08. For wire. 
%                             pend.r3 = (0.4/2)*10^-3; % For Silica Fibers. Alastair H 11/11/2008
                            % modified code for neck: MB 7 JUne 2010
                            pend.r3 = -1; %dummy
							pend.r3n = 0.0008/2; % radius at neck
							pend.r3m = 0.0004/2; % radius in midsection
 							pend.r3 = pend.r3n; % was r3m in Mathematica but needs to be like this for Matlab
                            pend.nl = 0.015; % neck length - specified directly instead of via nf (neck fraction) as in Mathematica
                            
                            % Number at each stage
                            pend.nwn = 2;
                            pend.nw1 = 4;
                            pend.nw2 = 4;
                            pend.nw3 = 4;
                            
                            % Moduli of elasticity
                            pend.Yn = 2.12000*10^+11; % "As Designed Parameter Set 2"; BNS 6/18/08
                            pend.Y1 = 2.12000*10^+11; % "As Designed Parameter Set 2"; BNS 6/18/08
                            pend.Y2 = 2.12000*10^+11; % "As Designed Parameter Set 2"; BNS 6/18/08
%                             pend.Y3 = 2.12000*10^+11; % BNS 6/18/08
                            pend.Y3 = 7.2*10^10; % For Silica Fibers. Peter Fritschel 11/11/2008                            

                            % Obsolete: ribbon parameters
                            pend.twistlength = 0; 				% T040214-01 
                            pend.d3tr = 1.0000*10^-03;	% T040214-01 
                            pend.d4tr = 1.0000*10^-03;	% T040214-01 
                            
                            % X distance of wire from center line
                            pend.sn = 0; 	  % T040214-01 
                            pend.su = 0.003;  % T040214-01 
                            pend.si = 0.003;  % T040214-01 
                            pend.sl = 0.015;  % T040214-01 
                            
                            % y distance of wire attatchment points from center
                            pend.nn0 = 0.250;  % T040214-01, also "As Designed Parameter Set 2"
                            pend.nn1 = 0.090;  % T040214-01, also "As Designed Parameter Set 2"
                            pend.n0 = 0.200;  % T040214-01, also "As Designed Parameter Set 2" 
                            pend.n1 = 0.060;  % T040214-01, also "As Designed Parameter Set 2" 
                            pend.n2 = 0.140;  % T040214-01, also "As Designed Parameter Set 2" 
%                             pend.n3 = 0.1765;  % Email from Marielle 6/15/10
                            pend.n3 = 0.1775;  % from drawings, BNS 22 June 2010
                            pend.n4 = 0.17025; % Email from Marielle 4/27/10                   
                            pend.n5 = 0.17025; % Email from Marielle 4/27/10
                            
                            % sine of angle of wires
                            sin = (pend.nn1-pend.nn0)/pend.ln;
                            si1 = (pend.n1-pend.n0)/pend.l1;
                            si2 = (pend.n3-pend.n2)/pend.l2;
                            si3 = (pend.n5-pend.n4)/pend.l3;                           
                            
                             
                            %%%%%%%%%%%%%%%%%%%%%%%%%%%%
                            % Blade Spring Stiffnesses %
                            %%%%%%%%%%%%%%%%%%%%%%%%%%%%                                                        
                                
							% Z Stiffnesses: Note that these stiffnesses represent individual springs; multiply by 2 to get the siffness between the masses.
                            pend.kcn = 1429.45595883388; % grad_descent_fit_z_bfgs_28July2010_part1
                            pend.kc1 = 1648.69334920402; % grad_descent_fit_z_bfgs_28July2010_part1
                            pend.kc2 = 2382.96853678021; % grad_descent_fit_z_bfgs_28July2010_part1
%                             pend.kcn = 1417.312466901349;
%                             pend.kc1 = 1659.516198981492;
%                             pend.kc2 = 2432.594459978795;
                            
                            % X stiffnesses
                            pend.kxn = 1.0*10^5; % as for middle, also "As Designed Parameter Set 2"
                            pend.kx1 = 1.0*10^5; % Justin 11/29/05, also "As Designed Parameter Set 2"
                            pend.kx2 = 0.8*10^5; % "As Designed Parameter Set 2"            
                            
                            % Blade stiffness correction parameters. Mark
                            % Barton said that the precise values here don't
                            % matter since the z stiffnesses above were already fit. BNS 5/27/09 
                            ffn = 0.807; % from Ian's data, 11/30/05 
                            ff1 = 0.641; % from Ian's data, 11/30/05 
                            ff2 = 0.608; % from Ian's data, 11/30/05                             
                            kffn = 1 + ffn*tan(asin(sin));
                            kff1 = 1 + ff1*tan(asin(si1));
                            kff2 = 1 + ff2*tan(asin(si2));
                            
                            
                            %%%%%%%%%%%%%%%%%%%%%%%%%%%%
                            % d's (wire z break offs)  %
                            %%%%%%%%%%%%%%%%%%%%%%%%%%%%
                            
                            % Added to pend structure definition for
                            % convenience of d's. T080096-00-K. BNS 6/18/2008
                            pend.mn3 = pend.mn+pend.m1+pend.m2+pend.m3;
                            pend.m13 = pend.m1+pend.m2+pend.m3;
                            pend.m23 = pend.m2+pend.m3;
                            pend.cn=(pend.ln^2-(pend.nn1-pend.nn0)^2)^0.5/pend.ln;	%cos(omegan)
                            pend.c1=(pend.l1^2-(pend.n1-pend.n0)^2)^0.5/pend.l1;	%cos(omega1)
                            pend.c2=(pend.l2^2-(pend.n3-pend.n2)^2)^0.5/pend.l2;	%cos(omega2)
                            pend.c3=(pend.l3^2-(pend.n5-pend.n4)^2)^0.5/pend.l3;	%cos(omega3)
                            pend.flexn = sqrt(2*((1/4)*pi*pend.rn^4)*pend.Yn/pend.mn3/pend.g)*pend.cn^(3/2); % flexn = 0.004534992483623; 
                            pend.flex1 = sqrt(4*((1/4)*pi*pend.r1^4)*pend.Y1/pend.m13/pend.g)*pend.c1^(3/2); % flex1 = 0.002747104240021; 
                            pend.flex2 = sqrt(4*((1/4)*pi*pend.r2^4)*pend.Y2/pend.m23/pend.g)*pend.c2^(3/2); % flex2 = 0.002926142794287; 
                            pend.flex3 = 0; % d3, d4 and l3 are all effective values
                                                                           
                            %d correction for lateral blade compliance.
                            %Added to pend structure definition for
                            %convenience of d's. T080096-00-K. BNS 6/18/2008
                            pend.bend1 = pend.g*(pend.m1+pend.m2+pend.m3)/(2*pend.kx1);
                            pend.bend2 = pend.g*(pend.m2+pend.m3)/(2*pend.kx2);
                            
                            pend.dm = (1-0.9609906717849997)/1000 - pend.flexn;% bfgs_monolithic_x_y_z_yaw_pitch_roll_29July2010d_part1
                            pend.dn = (1-0.735501089622135)/1000 - pend.flex1 + pend.bend1; % bfgs_monolithic_x_y_z_yaw_pitch_roll_29July2010d_part1
                            pend.d0 = (1+1.393824700702)/1000 - pend.flex1; % bfgs_monolithic_x_y_z_yaw_pitch_roll_29July2010d_part1, includes -1 mm on fit result to make more realiztic CM position
                            pend.d1 = (1-0.115974101777530)/1000 - pend.flex2 + pend.bend2; % bfgs_monolithic_x_y_z_yaw_pitch_roll_29July2010d_part1, includes +1.277641122674235 mm on fit result to make more realiztic CM position, where 1.277641122674235 = (m1+m2+m3)/(m2+m3)
                            pend.d2 = 0.3/1000 - pend.flex2;%
                            pend.d3 = (4.3-1.750244189175000)/1000; % bfgs_monolithic_x_y_z_yaw_pitch_roll_29July2010d_part1. Redefined as flex point relative to CM. Brett Shapiro July 2010.
                            pend.d4 = (4.3-2.045280917079000)/1000; % bfgs_monolithic_x_y_z_yaw_pitch_roll_29July2010d_part1. Redefined as flex point relative to CM. Brett Shapiro July 2010.
                               
                        	pend.l3 = 0.602-pend.d3-pend.d4; % effective (flex3==0) value for tl3=0.602, and effective d3 and d4 as above.
                    
                            %%%%%%%%%%%%%%%%%%%%%%%%%%%%
                            %    Fiber Stiffnesses     %
                            %%%%%%%%%%%%%%%%%%%%%%%%%%%%
                            pend.kw3 = 32963.3; % grad_descent_fit_z_bfgs_28July2010_part1
%                             pend.kw3 = 31634; % from FE: Alan Cumming 14 July 2010
                            % !!MB - define pend.kw3 to override vertical calc and keep bounce mode right even as pend.flex3 uses neck thickness
%                             pend.kw3n = pend.Y3*pi*pend.r3n^2/pend.nl*pend.nw3/2; % stiffness of neck sections
%                             pend.kw3m = pend.Y3*pi*pend.r3m^2/(pend.l3-2*pend.nl)*pend.nw3/2; % stiffness of midsection
%                             pend.kw3 = 1/(1/pend.kw3m+2/pend.kw3n); % net longitudinal stiffness per side = 31226                            
                                                                                
% Useful Density values (kg/m^3), BNS 5/9/09
% Density of 304 stainless steel  8000    http://www.azom.com/Details.asp?ArticleID=965
% Density of 5083 aluminum        2650    http://www.azom.com/Details.asp?ArticleID=2804
% Density of fused silica         2201    http://www.sciner.com/Opticsland/FS.htm
% Density of air                  1.225   at 20 C, sea level, 20% humididty; http://en.wikipedia.org/wiki/Atmospheric_pressure

% poisson's ratio for silica = 0.17 % Liam: 26 May 2010

% Other notes:
% Mass of each ear is approximately 0.022 kg; approximated by hand from
% D080751, BNS 20June 2010. This happens to be the same mass as the steel prisms used on the
% test mass during the LASTI wire hang;
% The mass of the PUM silica prisms are each 0.004 kg. From Marielle's email on 15
% June 2010, and from hand calcutions by BNS on 20 June 2010.
  