%adapted from Calum Torrie's ssmake4p by Ken Strain 3/01
%yaw and roll bugs fixed?  
% 
% 2/14/02, Mark Barton: 
%   corrected quad matrix elements derived by generalizing 
%   Calum's triple matrix elements using Mathematica
%   rename to ssmake4pv2eMB
% 2/24/05, Mark Barton: 
%   new matrix elements with more realistic blades
%   generated from scratch in Mathematica
%   rename to ssmake4pv2eMB2
% 3/30/05, Mark Barton: 
%   adjust sign of certain elements to match
%   conventions in Calum's original code 

% 12/12/05, Mark Barton: 
%   allow for lateral model with backward
%   compatibility to older elements 
%   rename to ssmake4pv2eMB3

% 3/30/06, Mark Barton
% eliminate use of && operator for backwards compatibility with R6

% 4/6/06, Mark Barton
% rename ssmake4pv2eMB4
% allow for ribbons

% 4/26/06, Mark Barton
% include calculation of useful stuff formerly in quadopt.m: pend.tln, pend.tl1, pend.tl2, 
%  pend.tl3, pend.l_suspoint_to_centreofoptic and pend.l_suspoint_to_bottomofoptic
% force calculation of flexn,... flex3 even if stage2 not set; export to pend

% 5/9/06, Mark Barton
% If pend.kcn is defined, use directly as kcn, rather than calculating kcn from
% ufcn. Similarly for pend.kc1 and pend.kc2.

% 9/15/06, Mark Barton
% Removed erroneous factor of 1/4 in M31 and M32 for ribbons

% 12/24/06, Mark Barton
% Added feature: if there is a string paramfile defined, it is used as the 
% parameter file name instead of quadopt.

% 12/31/06, Mark Barton
% Cleaned up input order, renamed ssmake4pv2eMB4c.m

% 2/6/07, Mark Barton
% Reworked for full matrices, renamed ssmake4pv2eMB4f.m

% 6/7/10, Mark Barton, Brett Shapiro
% Allow pend.kw3 defined in quadopt.m to override local calculation, so as to allow for dumbbell fibres

% 8/3/2010, Brett Shapiro
% Added extra offdiagonal inertia parameter on the UIM, Im1yz, which adds
% z and pitch coupling due to a front to back translation of the center of
% mass. This modification is to reflect the as built monolithic quad at
% LASTI. Similar parameters were added for the other masses.
% Changed handling of flex3 (but see below).
% Added interface to Brett's parameter fitting code (but see below).

% 8/12/2010, Mark Barton and Brett Shapiro
% General tidy-up. Removed interface to parameter fitting code.
% Undid change to flex3. If user has effective values of d3 and d4 from ANSYS,
% recommended procedure is to have quadopt.m set flex3=0 and l3 such that d3+l3+d4 equals desired tl3.

global pend
pff = 0;
if exist('paramfile')
    if ischar(paramfile)
        if length(paramfile)>=1
            pff = 1;
            eval(paramfile);
        end
    end
end
if not(pff)
    quadopt;
end


% general redefinition of variables to simplify notation
% and cope with different pendulum designs

% Make sure all flags are defined
if not(isfield(pend,'stage2'))
    pend.stage2=0; % define, default to false
end
if not(isfield(pend,'ribbon') )
    pend.ribbon=0; % define, default to false
end

g = pend.g;
Yn   = pend.Yn;
Y1   = pend.Y1;
Y2   = pend.Y2;
Y3   = pend.Y3;
if isfield(pend, 'kcn')
    kcn = pend.kcn;
    pend.ufcn = sqrt(2*kcn/pend.mn)/2/pi;
else
    kcn	=  1/2 * (2*pi*pend.ufcn)^2*pend.mn;
    pend.kcn = kcn;
end
if isfield(pend, 'kc1')
    kc1 = pend.kc1;
    pend.ufc1 = sqrt(2*kc1/pend.m1)/2/pi;
else
    kc1	=  1/2 * (2*pi*pend.ufc1)^2*pend.m1;
    pend.kc1 = kc1;
end
if isfield(pend, 'kc2')
    kc2 = pend.kc2;
    pend.ufc2 = sqrt(2*kc2/pend.m2)/2/pi;
else
    kc2	=  1/2 * (2*pi*pend.ufc2)^2*pend.m2;
    pend.kc2 = kc2;
end

% for backward compatibility, default off-axis MOI terms to zero
if not(isfield(pend, 'Inxy'))
    pend.Inxy = 0;
end
if not(isfield(pend, 'Inyz'))
    pend.Inyz = 0;
end
if not(isfield(pend, 'Inzx'))
    pend.Inzx = 0;
end
if not(isfield(pend, 'I1xy'))
    pend.I1xy = 0;
end
if not(isfield(pend, 'I1yz'))
    pend.I1yz = 0;
end
if not(isfield(pend, 'I1zx'))
    pend.I1zx = 0;
end
if not(isfield(pend, 'I2xy'))
    pend.I2xy = 0;
end
if not(isfield(pend, 'I2yz'))
    pend.I2yz = 0;
end
if not(isfield(pend, 'I2zx'))
    pend.I2zx = 0;
end
if not(isfield(pend, 'I3xy'))
    pend.I3xy = 0;
end
if not(isfield(pend, 'I3yz'))
    pend.I3yz = 0;
end
if not(isfield(pend, 'I3zx'))
    pend.I3zx = 0;
end

Inxy = pend.Inxy;
Inyz = pend.Inyz;
Inzx = pend.Inzx;
I1xy = pend.I1xy;
I1yz = pend.I1yz;
I1zx = pend.I1zx;
I2xy = pend.I2xy;
I2yz = pend.I2yz;
I2zx = pend.I2zx;
I3xy = pend.I3xy;
I3yz = pend.I3yz;
I3zx = pend.I3zx;

if not(isfield(pend,'Imnyz'))
    pend.Imnyz = 0;
end
if not(isfield(pend,'Im1yz'))
    pend.Im1yz = 0;
end
if not(isfield(pend,'Im2yz'))
    pend.Im2yz = 0;
end
if not(isfield(pend,'Im3yz'))
    pend.Im3yz = 0;
end
Imnyz = pend.Imnyz;
Im1yz = pend.Im1yz;
Im2yz = pend.Im2yz;
Im3yz = pend.Im3yz;

ln   = pend.ln;
l1   = pend.l1;
l2   = pend.l2;
l3   = pend.l3;
kwn	=pend.Yn*pi*pend.rn^2/ln*pend.nwn/2; % vertical stiffness of wires
kw1	=pend.Y1*pi*pend.r1^2/l1*pend.nw1/2;	
kw2	=pend.Y2*pi*pend.r2^2/l2*pend.nw2/2;

% Modification by Mark Barton 7 June 2010 to allow kw3 defined in quadopt.m to take precedence
% and thereby allow dumbbell fibres to be specified correctly.
if not(isfield(pend,'kw3')) % vertical stiffness of fibers
    if pend.ribbon
        kw3	=pend.Y3*pend.W3*pend.t3/l3*pend.nw3/2;
    else
        kw3	=pend.Y3*pi*pend.r3^2/l3*pend.nw3/2;	
    end
else
    kw3 = pend.kw3;
end
pend.kwn = kwn;
pend.kw1 = kw1;
pend.kw2 = kw2;
pend.kw3 = kw3;
% End modifications: MB 7 June 2010

%********************************************************************
% allows choice of 2 wires to set separation to zero
sm = 0; % separation of top wires at structure
sn = 0; % separation of top wires at mass N

s0=pend.su;
s1=pend.su;
s2=pend.si;
s3=pend.si;
s4=pend.sl;
s5=pend.sl;

dm=pend.dm;
dn=pend.dn;
d0=pend.d0;
d1=pend.d1;
d2=pend.d2;
d3=pend.d3;
d4=pend.d4;


%********************************************************************
mn = pend.mn;
m1 = pend.m1;
m2 = pend.m2;
m3 = pend.m3;
Inx = pend.Inx;
I1x = pend.I1x;
I2x = pend.I2x;
I3x = pend.I3x;
Iny = pend.Iny;
I1y = pend.I1y;
I2y = pend.I2y;
I3y = pend.I3y;
Inz = pend.Inz;
I1z = pend.I1z;
I2z = pend.I2z;
I3z = pend.I3z;

mn3  = mn+m1+m2+m3;
m13	= m1+m2+m3;
m23	= m2+m3;

nn0 = pend.nn0;
nn1 = pend.nn1;
n0  = pend.n0;
n1  = pend.n1;
n2  = pend.n2;
n3  = pend.n3;
n4  = pend.n4;
n5  = pend.n5;

%***********************************************************************************
% cosine and sine of the angle the wire makes with the vertical (z)

sin=(nn1-nn0)/ln;			%sin(omegan)
si1=(n1-n0)/l1;			%sin(omega1)
si2=(n3-n2)/l2;			%sin(omega2)
si3=(n5-n4)/l3;			%sin(omega3)	

cn=(ln^2-(nn1-nn0)^2)^0.5/ln;	%cos(omegan)
c1=(l1^2-(n1-n0)^2)^0.5/l1;	%cos(omega1)
c2=(l2^2-(n3-n2)^2)^0.5/l2;	%cos(omega2)
c3=(l3^2-(n5-n4)^2)^0.5/l3;	%cos(omega3)

%********************************************************
bd = pend.bd;
%********************************************************************

kn = kwn;
k1 = kw1;
k2 = kw2;
k3 = kw3;
su=pend.su;
si=pend.si;
sl=pend.sl;

% Vertical distances between centres of mass 
pend.tln = sqrt(pend.ln^2 - (pend.nn0-pend.nn1)^2) + pend.dm;
pend.tl1 = sqrt(pend.l1^2 - (pend.n0-pend.n1)^2) + pend.dn + pend.d0;
pend.tl2 = sqrt(pend.l2^2 - (pend.n2-pend.n3)^2) + pend.d1 + pend.d2;
pend.tl3 = sqrt(pend.l3^2 - (pend.n4-pend.n5)^2) + pend.d3 + pend.d4;

% Distance to the centre of mass from suspension point 
pend.l_suspoint_to_centreofoptic  =  pend.tln +pend.tl1+pend.tl2+pend.tl3;

% Distance to the bottom of the test mass from suspension point 
pend.l_suspoint_to_bottomofoptic  =  pend.tln +pend.tl1+pend.tl2+pend.tl3+pend.tr;

%%%%%% Mark's modificatio for fiber neck
% pi = 4*atan(1);
Mn1 = (1/4)*pi*pend.rn^4;
M11 = (1/4)*pi*pend.r1^4;
M21 = (1/4)*pi*pend.r2^4;
if not(isfield(pend,'flexn'))
	pend.flexn = sqrt(2*Mn1*Yn/mn3/g)*cn^(3/2);
end
if not(isfield(pend,'flex1'))
	pend.flex1 = sqrt(4*M11*Y1/m13/g)*c1^(3/2);
end
if not(isfield(pend,'flex2'))
	pend.flex2 = sqrt(4*M21*Y2/m23/g)*c2^(3/2);
end
if not(isfield(pend,'flex3'))
	if pend.ribbon
	    M31 = pend.W3*pend.t3^3/12;
	else
	    M31 = (1/4)*pi*pend.r3^4;
	end
	pend.flex3 = sqrt(4*M31*Y3/m3/g)*c3^(3/2); % for long/pitch, yaw and vertical
end
if not(isfield(pend,'flex3tr'))
	if pend.ribbon
	    M32 = pend.W3^3*pend.t3/12;
	else
	    M32 = (1/4)*pi*pend.r3^4;
	end
	pend.flex3tr = sqrt(4*M32*Y3/m3/g)*c3^(3/2); % for trans/roll, with M32 instead of M31
end

flexn = pend.flexn;
flex1 = pend.flex1;
flex2 = pend.flex2;
flex3 = pend.flex3; % for long/pitch, yaw and vertical; see below for trans/roll
%%%%%%%%%%%%%%%%%%%%%%%%%%%%

if pend.stage2
    % apply fudges to approximate Mathematica Stage2 results
    dm = dm + flexn;
    dn = dn + flex1;
    d0 = d0 + flex1; 
    d1 = d1 + flex2;
    d2 = d2 + flex2;
    d3 = d3 + flex3;
    d4 = d4 + flex3; 
    ln = ln - 2*flexn/cn;
    l1 = l1 - 2*flex1/c1;
    l2 = l2 - 2*flex2/c2;
    l3 = l3 - 2*flex3/c3;
    nn0 = nn0 + sin*flexn/cn;
    nn1 = nn1 - sin*flexn/cn;
    n0 = n0 + si1*flex1/c1;
    n1 = n1 - si1*flex1/c1;
    n2 = n2 + si2*flex2/c2;
    n3 = n3 - si2*flex2/c2;
    n4 = n4 + si3*flex3/c3;
    n5 = n5 - si3*flex3/c3;
end

newelements=0; 
if isfield(pend,'kxn')
    if isfield(pend,'kx1') 
        if isfield(pend,'kx2')
            % lateral compliances have been defined - use lateral model matrix
            % elements

            kxn = pend.kxn;
            kx1 = pend.kx1;
            kx2 = pend.kx2;

            symbexport4latfull
            
            newelements = 1;
        end
    end   
end

if not(newelements)
    symbexport4full
end

% allow for front-back translations of the CMs to include the as-built shift of the UIM CM in the LASTI monolithic quad
km(3,5) = Imnyz;
km(5,3) = Imnyz;
km(9,11) = Im1yz;
km(11,9) = Im1yz;
km(15,17) = Im2yz;
km(17,15) = Im2yz;
km(21,23) = Im3yz;
km(23,21) = Im3yz;

mbquadA = [...
    zeros(24) eye(24)
    (-km)\(xm-cqxm'/qm*cqxm) -bd*eye(24)
];

bm = (-km)\(cxsm-cqxm'/qm*cqsm); % ground displacement inputs: x,y,z,yaw,pitch,roll
bm2 = km\eye(24); % coordinate force inputs: pitchn,xn,pitch1,x1,...

mbquadB = [...
    zeros(24,30)
    bm bm2
];

mbquadC = [...
    eye(24) zeros(24,24)
];
 
 mbquadD = [...
    zeros(24,30)
 ];

mbquad = ss(mbquadA,mbquadB,mbquadC,mbquadD);


